﻿////
/// Copyright(C) 2020 Micronet Co. All Rights Reserved.
//
using System;

namespace EgSDB
{
    /// <summary>
    /// サービスインジケータ名
    /// </summary>
    public class EgSDBIndName
    {
        /// <summary>
        /// サービスの起動状態
        /// </summary>
        public string Status
        {
            get { return m_srStatus; }
        }
        private string m_srStatus = "";

        /// <summary>
        /// サービスのタグリフレッシュ実行状態
        /// </summary>
        public string Run
        {
            get { return m_srRun; }
        }
        private string m_srRun = "";

        /// <summary>
        /// サービスのエラー状態
        /// </summary>
        public string Error
        {
            get { return m_srError; }
        }
        private string m_srError = "";

        /// <summary>
        /// 稼働カウンタ
        /// </summary>
        public string Live
        {
            get { return m_srLive; }
        }
        private string m_srLive = "";

        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="srMyName">自身のプログラム名</param>
        public EgSDBIndName(string srMyName)
        {
            // サービスの起動状態
            m_srStatus = "SERVICE." + srMyName + ".Status";

            // サービスのタグリフレッシュ実行状態
            m_srRun = "SERVICE." + srMyName + ".Run";

            // サービスのエラー状態
            m_srError = "SERVICE." + srMyName + ".Error";

            // 稼働カウンタ
            m_srLive = "SERVICE." + srMyName + ".Live";
        }
        /// <summary>
        /// 値を再設定
        /// </summary>
        /// <param name="srMyName"></param>
        public void ReSetEgSDBIndName(string srMyName)
        {
            // サービスの起動状態
            m_srStatus = "SERVICE." + srMyName + ".Status";

            // サービスのタグリフレッシュ実行状態
            m_srRun = "SERVICE." + srMyName + ".Run";

            // サービスのエラー状態
            m_srError = "SERVICE." + srMyName + ".Error";

            // 稼働カウンタ
            m_srLive = "SERVICE." + srMyName + ".Live";
        }
    }

    /// <summary>
    /// サービスインジケータ値
    /// </summary>
    public class EgSDBIndVal
    {
        /// <summary>
        /// サービスの起動状態
        /// </summary>
        public Byte m_byStatus = 0;

        /// <summary>
        /// サービスのタグリフレッシュ実行状態
        /// </summary>
        public bool m_boRun = false;

        /// <summary>
        /// サービスのエラー状態
        /// </summary>
        public bool m_boError = false;

        /// <summary>
        /// 稼働カウンタ
        /// </summary>
        public UInt32 m_dwLive = 0;
    }

    /// <summary>
    /// サービスプロパティタグ名
    /// </summary>
    public class EgSDBTagName
    {

        /// <summary>
        /// 最新のエラーコード
        /// </summary>
        public string LastErr
        {
            get { return m_srLastErr; }
        }
        private string m_srLastErr = "";

        /// <summary>
        /// 自動起動設定
        /// </summary>
        public string AutoRun
        {
            get { return m_srAutoRun; }
        }
        private string m_srAutoRun;

        /// <summary>
        /// ファイル単位サイズ(バイト単位)
        /// </summary>
        public string FragmentSize
        {
            get { return m_srFragmentSize; }
        }
        private string m_srFragmentSize;

        /// <summary>
        /// 残りのファイルサイズ(バイト単位)
        /// </summary>
        public string FileFreeSize
        {
            get { return m_srFileFreeSize; }
        }
        private string m_srFileFreeSize;

        /// <summary>
        /// 最新のレコード構成番号
        /// </summary>
        public string FormatNumber
        {
            get { return m_srFormatNumber; }
        }
        private string m_srFormatNumber;

        /// <summary>
        /// ファイル書き込み位置
        /// </summary>
        public string AddPointer
        {
            get { return m_srAddPointer; }
        }
        private string m_srAddPointer;

        /// <summary>
        /// 記録容量に保存されているファイルの個数
        /// </summary>
        public string FileCount
        {
            get { return m_srFileCount; }
        }
        private string m_srFileCount;

        /// <summary>
        /// 記録容量
        /// </summary>
        public string CapacitySize
        {
            get { return m_srCapacitySize; }
        }
        private string m_srCapacitySize;

        /// <summary>
        /// 残り記録容量
        /// </summary>
        public string CapacityFreeSize
        {
            get { return m_srCapacityFreeSize; }
        }
        private string m_srCapacityFreeSize;

        /// <summary>
        /// 残り記録容量
        /// </summary>
        public string StorePath
        {
            get { return m_srStorePath; }
        }
        private string m_srStorePath;

        /// <summary>
        /// 計測回数
        /// </summary>
        public string MeasureCount
        {
            get { return m_srMeasureCount; }
        }
        private string m_srMeasureCount;

        /// <summary>
        /// 合計レコード追加時間（ミリ秒）
        /// </summary>
        public string TotalRecTime
        {
            get { return m_srTotalRecTime; }
        }
        private string m_srTotalRecTime;

        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="srMyName">自身のプログラム名</param>
        public EgSDBTagName(string srMyName)
        {
            // 最新のエラーコード
            m_srLastErr = "SERVICE." + srMyName + ".LastErr";
            // 自動起動設定
            m_srAutoRun = "SERVICE." + srMyName + ".AutoRun";
            // ファイル単位サイズ(バイト単位)
            m_srFragmentSize = "SERVICE." + srMyName + ".FragmentSize";
            // 残りのファイルサイズ(バイト単位)
            m_srFileFreeSize = "SERVICE." + srMyName + ".FileFreeSize";
            // 最新のレコード構成番号
            m_srFormatNumber = "SERVICE." + srMyName + ".FormatNumber";
            // ファイル書き込み位置
            m_srAddPointer = "SERVICE." + srMyName + ".AddPointer";
            // ファイルの個数
            m_srFileCount = "SERVICE." + srMyName + ".FileCount";
            // 記録容量
            m_srCapacitySize = "SERVICE." + srMyName + ".CapacitySize";
            // 残り記録容量
            m_srCapacityFreeSize = "SERVICE." + srMyName + ".CapacityFreeSize";
            // 収納パス
            m_srStorePath = "SERVICE." + srMyName + ".StorePath";
            // 計測回数
            m_srMeasureCount = "SERVICE." + srMyName + ".MeasureCount";
            // 合計レコード追加時間（ミリ秒）
            m_srTotalRecTime = "SERVICE." + srMyName + ".TotalRecTime";
        }
        /// <summary>
        /// タグ名再設定
        /// </summary>
        /// <param name="srMyName">自身のプログラム名</param>
        public void ReSetEgSDBTagName(string srMyName)
        {
            // 最新のエラーコード
            m_srLastErr = "SERVICE." + srMyName + ".LastErr";
            // 自動起動設定
            m_srAutoRun = "SERVICE." + srMyName + ".AutoRun";
            // ファイル単位サイズ(バイト単位)
            m_srFragmentSize = "SERVICE." + srMyName + ".FragmentSize";
            // 残りのファイルサイズ(バイト単位)
            m_srFileFreeSize = "SERVICE." + srMyName + ".FileFreeSize";
            // 最新のレコード構成番号
            m_srFormatNumber = "SERVICE." + srMyName + ".FormatNumber";
            // ファイル書き込み位置
            m_srAddPointer = "SERVICE." + srMyName + ".AddPointer";
            // ファイルの個数
            m_srFileCount = "SERVICE." + srMyName + ".FileCount";
            // 記録容量
            m_srCapacitySize = "SERVICE." + srMyName + ".CapacitySize";
            // 残り記録容量
            m_srCapacityFreeSize = "SERVICE." + srMyName + ".CapacityFreeSize";
            // 収納パス
            m_srStorePath = "SERVICE." + srMyName + ".StorePath";
            // 計測回数
            m_srMeasureCount = "SERVICE." + srMyName + ".MeasureCount";
            // 合計レコード追加時間（ミリ秒）
            m_srTotalRecTime = "SERVICE." + srMyName + ".TotalRecTime";
        }
    }

    /// <summary>
    /// サービスプロパティタグ値
    /// </summary>
    public class EgSDBTagVal
    {

        /// <summary>
        /// 最新のエラーコード
        /// </summary>
        public Int32 m_inLastErr = 0;

        /// <summary>
        /// 自動起動設定
        /// </summary>
        public bool m_boAutoRun = true;

        /// <summary>
        /// ファイル単位サイズ(バイト単位)
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// 残りのファイルサイズ(バイト単位)
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// 最新のレコード構成番号
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// ファイル書き込み位置
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// ファイル個数
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// 記録容量
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// 残り記録容量
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// 収納パス
        /// </summary>
        /// タグ生成のみ、変数宣言なし

        /// <summary>
        /// 計測回数
        /// </summary>
        public Int32 m_inMeasureCount;

        /// <summary>
        /// 合計レコード追加時間（ミリ秒）
        /// </summary>
        public double m_doTotalRecTime;
    }

}
